Documentation
¶
Index ¶
- Variables
- type BuildStatus
- type BuildableStatus
- type ConduitMethod
- type Cursor
- type DifferentialDiff
- type DifferentialRevision
- type DifferentialRevisionReviewers
- type DiffusionCommit
- type Edge
- type EdgeType
- type ManiphestTask
- type ManiphestTaskTranscation
- type PHIDResult
- type PasteItem
- type PhrictionDocument
- type Project
- type RemarkupDocument
- type Repository
- type Session
- type StagingRepository
- type User
Constants ¶
This section is empty.
Variables ¶
var ( // BuildableStatusPreparing - builbable is being prepared. BuildableStatusPreparing = "preparing" // BuildableStatusBuilding - building is in progress. BuildableStatusBuilding = "building" // BuildableStatusPassed - all blocking builds of builtable have passed. BuildableStatusPassed = "passed" // BuildableStatusFailed - some builds of buildable have failed. BuildableStatusFailed = "failed" // BuildStatusInactive - build is inactive. BuildStatusInactive = "inactive" // BuildStatusPending - building is pending. BuildStatusPending = "pending" // BuildStatusBuilding - building is in progress. BuildStatusBuilding = "building" // BuildStatusPassed - build passed. BuildStatusPassed = "passed" // BuildStatusFailed - build failed. BuildStatusFailed = "failed" // BuildStatusAborted - build is aborted. BuildStatusAborted = "aborted" // BuildStatusError - build got an error. BuildStatusError = "error" // BuildStatusPaused - build is paused. BuildStatusPaused = "paused" // BuildStatusDeadlocked - build is deadlocked. BuildStatusDeadlocked = "deadlocked" )
Functions ¶
This section is empty.
Types ¶
type BuildStatus ¶ added in v0.13.0
type BuildStatus string
BuildStatus defines values supported by the statuses constraint.
type BuildableStatus ¶ added in v0.9.0
type BuildableStatus string
BuildableStatus defines values supported by the statuses constraint.
type ConduitMethod ¶ added in v0.2.0
type ConduitMethod struct {
Description string `json:"description"`
Params interface{} `json:"params"`
Return string `json:"return"`
}
ConduitMethod is a conduit method representation returned by `conduit.query`.
type Cursor ¶
type Cursor struct {
Limit uint64 `json:"limit"`
After uint64 `json:"after"`
Before uint64 `json:"before"`
}
Cursor represents the pagination cursor on many responses.
type DifferentialDiff ¶ added in v0.4.0
type DifferentialDiff struct {
ID string `json:"id"`
RevisionID string `json:"revisionID"`
DateCreated util.UnixTimestamp `json:"dateCreated"`
DateModified util.UnixTimestamp `json:"dateModified"`
SourceControlBaseRevision string `json:"sourceControlBaseRevision"`
SourceControlPath string `json:"sourceControlPath"`
SourceControlSystem string `json:"sourceControlSystem"`
Branch string `json:"branch"`
Bookmark string `json:"bookmark"`
CreationMethod string `json:"creationMethod"`
Description string `json:"description"`
UnitStatus string `json:"unitStatus"`
LintStatus string `json:"lintStatus"`
AuthorName string `json:"authorName"`
AuthorEmail string `json:"authorEmail"`
}
DifferentialDiff represents a specific diff within a Differential revision. A new diff is created every time you update a differential revision (that's what arc diff does duh).
NOTE: Two fields are missing from this struct:
- Changes (changes) is a list of a fairly complex data-structure with all hunks contained in this diff along with some dynamically typed metadata;
- Properties (properties) is another dynamically typed field which will be an empty list on a closed diff (as far as I can tell) or a fairly complex data-structure containing more metadata about the diff (info about the local commits and about arc's interaction with the staging area if you repository has one set up).
type DifferentialRevision ¶
type DifferentialRevision struct {
ID string `json:"id"`
PHID string `json:"phid"`
Title string `json:"title"`
URI string `json:"uri"`
DateCreated util.UnixTimestamp `json:"dateCreated"`
DateModified util.UnixTimestamp `json:"dateModified"`
AuthorPHID string `json:"authorPHID"`
Status constants.DifferentialStatusLegacy `json:"status"`
StatusName string `json:"statusName"`
Branch string `json:"branch"`
Summary string `json:"summary"`
TestPlan string `json:"testPlan"`
LineCount string `json:"lineCount"`
ActiveDiffPHID string `json:"activeDiffPHID"`
Diffs []string `json:"diffs"`
Commits []string `json:"commits"`
Reviewers DifferentialRevisionReviewers `json:"reviewers"`
CCs []string `json:"ccs"`
Hashes [][]string `json:"hashes"`
Auxiliary map[string]interface{} `json:"auxiliary"`
RepositoryPHID string `json:"repositoryPHID"`
}
DifferentialRevision represents a revision in Differential.
type DifferentialRevisionReviewers ¶ added in v0.6.0
DifferentialRevisionReviewers holds a list of reviewers of differential revision.
func (*DifferentialRevisionReviewers) UnmarshalJSON ¶ added in v0.6.0
func (r *DifferentialRevisionReviewers) UnmarshalJSON(b []byte) error
UnmarshalJSON ensures result of unmarshaling always is map[string]string despite if reviewers field in JSON holds a map (when reviewers exist) or empty slice (when there are no reviewers).
type DiffusionCommit ¶
type DiffusionCommit struct {
ID string `json:"id"`
PHID string `json:"phid"`
RepositoryPHID string `json:"repositoryPHID"`
Identifier string `json:"identifier"`
Epoch string `json:"epoch"`
URI string `json:"uri"`
IsImporting bool `json:"isImporting"`
Summary string `json:"summary"`
AuthorPHID string `json:"authorPHID"`
CommitterPHID string `json:"committerPHID"`
Author string `json:"author"`
AuthorName string `json:"authorName"`
AuthorEmail string `json:"authorEmail"`
Committer string `json:"committer"`
CommitterName string `json:"committerName"`
}
DiffusionCommit represents a commit in Diffusion.
type Edge ¶ added in v0.10.0
type Edge struct {
SourcePHID string `json:"sourcePHID"`
DestinationPHID string `json:"destinationPHID"`
EdgeType EdgeType `json:"edgeType"`
}
Edge is a relation between two objects on Phabricator. EdgeType defines the type of such relation (it can be parent, child, mention, etc.).
type EdgeType ¶ added in v0.10.0
type EdgeType string
EdgeType is available type of edge on phabricator.
var ( EdgeCommitRevision EdgeType = "commit.revision" EdgeCommitTask EdgeType = "commit.task" EdgeMention EdgeType = "mention" EdgeMentionedIn EdgeType = "mentioned-in" EdgeRevisionChild EdgeType = "revision.child" EdgeRevisionCommit EdgeType = "revision.commit" EdgeRevisionParent EdgeType = "revision.parent" EdgeRevisionTask EdgeType = "revision.task" EdgeTaskCommit EdgeType = "task.commit" EdgeTaskDuplicate EdgeType = "task.duplicate" EdgeTaskMergedIn EdgeType = "task.merged-in" EdgeTaskParent EdgeType = "task.parent" EdgeTaskRevision EdgeType = "task.revision" EdgeTaskSubtask EdgeType = "task.subtask" )
type ManiphestTask ¶
type ManiphestTask struct {
ID string `json:"id"`
PHID string `json:"phid"`
AuthorPHID string `json:"authorPHID"`
OwnerPHID string `json:"ownerPHID"`
CCPHIDs []string `json:"ccPHIDs"`
Status string `json:"status"`
StatusName string `json:"statusName"`
IsClosed bool `json:"isClosed"`
Priority string `json:"priority"`
PriorityColor string `json:"priorityColor"`
Title string `json:"title"`
Description string `json:"description"`
ProjectPHIDs []string `json:"projectPHIDs"`
URI string `json:"uri"`
Auxiliary interface{} `json:"auxiliary"`
ObjectName string `json:"objectName"`
DateCreated util.UnixTimestamp `json:"dateCreated"`
DateModified util.UnixTimestamp `json:"dateModified"`
DependsOnTaskPHIDs []string `json:"dependsOnTaskPHIDs"`
}
ManiphestTask represents a single task on Maniphest.
type ManiphestTaskTranscation ¶ added in v0.3.0
type ManiphestTaskTranscation struct {
TaskID string `json:"taskID"`
TransactionID string `json:"transactionID"`
TransactionPHID string `json:"transactionPHID"`
TransactionType string `json:"transactionType"`
OldValue interface{} `json:"oldValue"`
NewValue interface{} `json:"newValue"`
Comments string `json:"comments"`
AuthorPHID string `json:"authorPHID"`
DateCreated util.UnixTimestamp `json:"dateCreated"`
}
ManiphestTaskTranscation represents a single task's transcation on Maniphest.
type PHIDResult ¶
type PHIDResult struct {
PHID string `json:"phid"`
URI string `json:"uri"`
TypeName string `json:"typeName"`
Type string `json:"type"`
Name string `json:"name"`
FullName string `json:"fullName"`
Status string `json:"status"`
}
PHIDResult is a result item of phid operations.
type PasteItem ¶
type PasteItem struct {
ID uint64 `json:"id"`
ObjectName string `json:"objectName"`
PHID string `json:"phid"`
AuthorPHID string `json:"authorPHID"`
FilePHID string `json:"filePHID"`
Title string `json:"title"`
DateCreated util.UnixTimestamp `json:"dateCreated"`
Language string `json:"language"`
URI string `json:"uri"`
ParentPHID string `json:"parentPHID"`
Content string `json:"content"`
}
PasteItem is a result item for paste queries.
type PhrictionDocument ¶ added in v0.3.0
type PhrictionDocument struct {
PHID string `json:"phid"`
URI string `json:"uri"`
Slug string `json:"slug"`
Version int `json:"version,string"`
AuthorPHID string `json:"authorPHID"`
Title string `json:"title"`
Content string `json:"content"`
Status string `json:"status"`
Description string `json:"description"`
DateModified util.UnixTimestamp `json:"dateModified"`
}
PhrictionDocument represents a document in Phriction wiki.
type Project ¶
type Project struct {
ID string `json:"id"`
PHID string `json:"phid"`
Name string `json:"name"`
ProfileImagePHID string `json:"profileImagePHID"`
Icon string `json:"icon"`
Color string `json:"color"`
Members []string `json:"members"`
Slugs []string `json:"slugs"`
DateCreated util.UnixTimestamp `json:"dateCreated"`
DateModified util.UnixTimestamp `json:"dateModified"`
}
Project represents a single Phabricator Project.
type RemarkupDocument ¶ added in v0.3.0
type RemarkupDocument struct {
Content string `json:"content"`
}
RemarkupDocument is result of `remarkup.process` method.
type Repository ¶
type Repository struct {
ID string `json:"id"`
Name string `json:"name"`
PHID string `json:"phid"`
Callsign string `json:"callsign"`
Monogram string `json:"monogram"`
VCS string `json:"vcs"`
URI string `json:"uri"`
RemoteURI string `json:"remoteURI"`
Description string `json:"description"`
IsActive bool `json:"isActive"`
IsHosted bool `json:"isHosted"`
IsImporting bool `json:"isImporting"`
Encoding string `json:"encoding"`
Staging StagingRepository `json:"staging"`
}
Repository represents a single code repository.
type Session ¶
type Session struct {
SessionKey string `json:"sessionKey"`
ConnectionID int64 `json:"connectionID"`
}
Session is the conduit session state that will be sent in the JSON params as __conduit__.
type StagingRepository ¶
type StagingRepository struct {
Supported bool `json:"supported"`
Prefix string `json:"phabricator"`
URI string `json:"uri"`
}
StagingRepository represents a single staging code repository.